@@ -1,5 +1,6 @@
 class TextAnalysisHelpersException(Exception):
     """Base text analysis helpers exception"""
+
     pass
 
 
@@ -7,8 +8,9 @@ class WebPageDownloadError(TextAnalysisHelpersException):
     """Exception that is raised if there was an error while downloading the
     contents of a web page"""
 
-    def __init__(self, message=None, url=None, status_code=None,
-                 response=None):
+    def __init__(
+        self, message=None, url=None, status_code=None, response=None
+    ):
         """Create a new WebPageDownloadError object
 
         :param str|None message: the description of the error
@@ -17,19 +19,10 @@ class WebPageDownloadError(TextAnalysisHelpersException):
         :param str|None response: the response text
         """
         super(WebPageDownloadError, self).__init__(
-            message, url, status_code, response)
+            message, url, status_code, response
+        )
 
         self.message = message
         self.url = url
         self.status_code = status_code
         self.response = response
-
-
-class HtmlAnalysisError(TextAnalysisHelpersException):
-    """Exchaption raised when an error occurs during html analysis"""
-    pass
-
-
-class ContentExtractionFailed(HtmlAnalysisError):
-    """Exception that is raised when no content could be extracted"""
-    pass
