@@ -1,33 +1,20 @@
 from logging import getLogger
 
-from newspaper import Article
-from opengraph.opengraph import OpenGraph
-
+from articles.mss.extractors import MSSArticleExtractor
 
 logger = getLogger(__name__)
 
 
-def extract_page_content(url, html_content):
-    article = Article(url)
-    article.download(input_html=html_content)
-    article.parse()
+def extract_page_content(html_content):
+    article_extractor = MSSArticleExtractor()
 
-    return article
+    return article_extractor.extract_article(html_content)
 
 
 def extract_page_data(soup):
     title = soup.find("title")
 
-    return {
-        "title": title.text if title else None
-    }
-
-
-def extract_opengraph_data(html_content):
-    opengraph = OpenGraph()
-    opengraph.parser(html_content)
-
-    return opengraph if opengraph.is_valid() else None
+    return {"title": title.text if title else None}
 
 
 def extract_twitter_card(soup):
